.. _sardana-devel-overview:

==============
Overview
==============


.. toctree::
    :maxdepth: 2
    
    Global overview <overview>
    Pool <pool>
    Controller <controller>
    Motor <motor>
    Macro Server <macroserver>

